"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_createpricerequest import (
    DtoCreatePriceRequest,
    DtoCreatePriceRequestTypedDict,
)
from flexprice_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DtoCreateBulkPriceRequestTypedDict(TypedDict):
    items: List[DtoCreatePriceRequestTypedDict]


class DtoCreateBulkPriceRequest(BaseModel):
    items: List[DtoCreatePriceRequest]
