"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .s3jobconfig import S3JobConfig, S3JobConfigTypedDict
from .scheduledtaskentitytype import ScheduledTaskEntityType
from .scheduledtaskinterval import ScheduledTaskInterval
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoCreateScheduledTaskRequestTypedDict(TypedDict):
    connection_id: str
    entity_type: ScheduledTaskEntityType
    interval: ScheduledTaskInterval
    job_config: S3JobConfigTypedDict
    enabled: NotRequired[bool]


class DtoCreateScheduledTaskRequest(BaseModel):
    connection_id: str

    entity_type: ScheduledTaskEntityType

    interval: ScheduledTaskInterval

    job_config: S3JobConfig

    enabled: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["enabled"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
