"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_entitlementsource import DtoEntitlementSource, DtoEntitlementSourceTypedDict
from .dto_featureresponse import DtoFeatureResponse, DtoFeatureResponseTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoFeatureUsageSummaryTypedDict(TypedDict):
    current_usage: NotRequired[str]
    feature: NotRequired[DtoFeatureResponseTypedDict]
    is_enabled: NotRequired[bool]
    is_soft_limit: NotRequired[bool]
    is_unlimited: NotRequired[bool]
    next_usage_reset_at: NotRequired[str]
    sources: NotRequired[List[DtoEntitlementSourceTypedDict]]
    total_limit: NotRequired[int]
    usage_percent: NotRequired[str]


class DtoFeatureUsageSummary(BaseModel):
    current_usage: Optional[str] = None

    feature: Optional[DtoFeatureResponse] = None

    is_enabled: Optional[bool] = None

    is_soft_limit: Optional[bool] = None

    is_unlimited: Optional[bool] = None

    next_usage_reset_at: Optional[str] = None

    sources: Optional[List[DtoEntitlementSource]] = None

    total_limit: Optional[int] = None

    usage_percent: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "current_usage",
                "feature",
                "is_enabled",
                "is_soft_limit",
                "is_unlimited",
                "next_usage_reset_at",
                "sources",
                "total_limit",
                "usage_percent",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
