"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


SubscriptionStatus = Union[
    Literal[
        "active",
        "paused",
        "cancelled",
        "incomplete",
        "trialing",
        "draft",
    ],
    UnrecognizedStr,
]
