"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriptionstatus import SubscriptionStatus
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoSubscriptionSummaryTypedDict(TypedDict):
    archived_at: NotRequired[str]
    r"""archived_at timestamp (for old subscriptions)"""
    billing_anchor: NotRequired[str]
    r"""billing_anchor of the subscription"""
    created_at: NotRequired[str]
    r"""created_at timestamp"""
    current_period_end: NotRequired[str]
    r"""current_period_end of the subscription"""
    current_period_start: NotRequired[str]
    r"""current_period_start of the subscription"""
    id: NotRequired[str]
    r"""id of the subscription"""
    plan_id: NotRequired[str]
    r"""plan_id of the subscription"""
    status: NotRequired[SubscriptionStatus]


class DtoSubscriptionSummary(BaseModel):
    archived_at: Optional[str] = None
    r"""archived_at timestamp (for old subscriptions)"""

    billing_anchor: Optional[str] = None
    r"""billing_anchor of the subscription"""

    created_at: Optional[str] = None
    r"""created_at timestamp"""

    current_period_end: Optional[str] = None
    r"""current_period_end of the subscription"""

    current_period_start: Optional[str] = None
    r"""current_period_start of the subscription"""

    id: Optional[str] = None
    r"""id of the subscription"""

    plan_id: Optional[str] = None
    r"""plan_id of the subscription"""

    status: Optional[SubscriptionStatus] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "archived_at",
                "billing_anchor",
                "created_at",
                "current_period_end",
                "current_period_start",
                "id",
                "plan_id",
                "status",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
