"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriptionstatus import SubscriptionStatus
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoUpdateSubscriptionRequestTypedDict(TypedDict):
    cancel_at: NotRequired[str]
    cancel_at_period_end: NotRequired[bool]
    parent_subscription_id: NotRequired[str]
    r"""ParentSubscriptionID sets or clears the parent subscription. Omit to leave unchanged; send \"\" to clear."""
    status: NotRequired[SubscriptionStatus]


class DtoUpdateSubscriptionRequest(BaseModel):
    cancel_at: Optional[str] = None

    cancel_at_period_end: Optional[bool] = None

    parent_subscription_id: Optional[str] = None
    r"""ParentSubscriptionID sets or clears the parent subscription. Omit to leave unchanged; send \"\" to clear."""

    status: Optional[SubscriptionStatus] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["cancel_at", "cancel_at_period_end", "parent_subscription_id", "status"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
