"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .walletconfigpricetype import WalletConfigPriceType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class WalletConfigTypedDict(TypedDict):
    allowed_price_types: NotRequired[List[WalletConfigPriceType]]
    r"""AllowedPriceTypes is a list of price types that are allowed for the wallet
    nil means all price types are allowed
    """


class WalletConfig(BaseModel):
    allowed_price_types: Optional[List[WalletConfigPriceType]] = None
    r"""AllowedPriceTypes is a list of price types that are allowed for the wallet
    nil means all price types are allowed
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["allowed_price_types"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
