"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .status import Status
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Literal, Optional
from typing_extensions import NotRequired, TypedDict


QueryFilterOrder = Literal[
    "asc",
    "desc",
]


class QueryFilterTypedDict(TypedDict):
    expand: NotRequired[str]
    limit: NotRequired[int]
    offset: NotRequired[int]
    order: NotRequired[QueryFilterOrder]
    sort: NotRequired[str]
    status: NotRequired[Status]


class QueryFilter(BaseModel):
    expand: Optional[str] = None

    limit: Optional[int] = None

    offset: Optional[int] = None

    order: Optional[QueryFilterOrder] = None

    sort: Optional[str] = None

    status: Optional[Status] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["expand", "limit", "offset", "order", "sort", "status"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
