"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


CreditNoteReason = Union[
    Literal[
        "DUPLICATE",
        "FRAUDULENT",
        "ORDER_CHANGE",
        "UNSATISFACTORY",
        "SERVICE_ISSUE",
        "BILLING_ERROR",
        "SUBSCRIPTION_CANCELLATION",
    ],
    UnrecognizedStr,
]
