"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


FilterOperatorType = Literal[
    "eq",
    "contains",
    "not_contains",
    "gt",
    "lt",
    "in",
    "not_in",
    "before",
    "after",
]
