"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, HeaderMetadata, PathParamMetadata
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class HandleQuickbooksWebhookRequestTypedDict(TypedDict):
    tenant_id: str
    r"""Tenant ID"""
    environment_id: str
    r"""Environment ID"""
    intuit_signature: NotRequired[str]
    r"""QuickBooks webhook signature"""


class HandleQuickbooksWebhookRequest(BaseModel):
    tenant_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Tenant ID"""

    environment_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Environment ID"""

    intuit_signature: Annotated[
        Optional[str],
        pydantic.Field(alias="intuit-signature"),
        FieldMetadata(header=HeaderMetadata(style="simple", explode=False)),
    ] = None
    r"""QuickBooks webhook signature"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["intuit-signature"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
