"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_subscriptionscheduleresponse import (
    DtoSubscriptionScheduleResponse,
    DtoSubscriptionScheduleResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetPendingSchedulesResponseTypedDict(TypedDict):
    r"""List of pending schedules for a subscription"""

    count: NotRequired[int]
    r"""count is the number of pending schedules"""
    schedules: NotRequired[List[DtoSubscriptionScheduleResponseTypedDict]]
    r"""schedules is the list of pending schedules"""


class DtoGetPendingSchedulesResponse(BaseModel):
    r"""List of pending schedules for a subscription"""

    count: Optional[int] = None
    r"""count is the number of pending schedules"""

    schedules: Optional[List[DtoSubscriptionScheduleResponse]] = None
    r"""schedules is the list of pending schedules"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["count", "schedules"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
