"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel
from typing_extensions import TypedDict


class DtoCreateEnvironmentRequestTypedDict(TypedDict):
    name: str
    type: str


class DtoCreateEnvironmentRequest(BaseModel):
    name: str

    type: str
