"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from typing import Literal


InvoiceBillingReason = Literal[
    "SUBSCRIPTION_CREATE",
    "SUBSCRIPTION_CYCLE",
    "SUBSCRIPTION_UPDATE",
    "PRORATION",
    "MANUAL",
]
