"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, QueryParamMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ListAllSubscriptionSchedulesRequestTypedDict(TypedDict):
    pending_only: NotRequired[bool]
    r"""Filter to pending schedules only"""
    subscription_id: NotRequired[str]
    r"""Filter by subscription ID"""
    limit: NotRequired[int]
    r"""Limit results"""
    offset: NotRequired[int]
    r"""Offset for pagination"""


class ListAllSubscriptionSchedulesRequest(BaseModel):
    pending_only: Annotated[
        Optional[bool],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter to pending schedules only"""

    subscription_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Filter by subscription ID"""

    limit: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Limit results"""

    offset: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Offset for pagination"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["pending_only", "subscription_id", "limit", "offset"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
