"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


TransactionReason = Union[
    Literal[
        "INVOICE_PAYMENT",
        "FREE_CREDIT_GRANT",
        "SUBSCRIPTION_CREDIT_GRANT",
        "PURCHASED_CREDIT_INVOICED",
        "PURCHASED_CREDIT_DIRECT",
        "CREDIT_NOTE",
        "CREDIT_EXPIRED",
        "WALLET_TERMINATION",
        "MANUAL_BALANCE_DEBIT",
        "CREDIT_ADJUSTMENT",
    ],
    UnrecognizedStr,
]
