"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


SecretProvider = Union[
    Literal[
        "flexprice",
        "stripe",
        "s3",
        "hubspot",
        "razorpay",
        "chargebee",
        "quickbooks",
        "nomod",
        "moyasar",
    ],
    UnrecognizedStr,
]
