"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_debugtracker import DtoDebugTracker, DtoDebugTrackerTypedDict
from .dto_event import DtoEvent, DtoEventTypedDict
from .dto_featureusageinfo import DtoFeatureUsageInfo, DtoFeatureUsageInfoTypedDict
from .eventprocessingstatustype import EventProcessingStatusType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetEventByIDResponseTypedDict(TypedDict):
    debug_tracker: NotRequired[DtoDebugTrackerTypedDict]
    event: NotRequired[DtoEventTypedDict]
    processed_events: NotRequired[List[DtoFeatureUsageInfoTypedDict]]
    status: NotRequired[EventProcessingStatusType]


class DtoGetEventByIDResponse(BaseModel):
    debug_tracker: Optional[DtoDebugTracker] = None

    event: Optional[DtoEvent] = None

    processed_events: Optional[List[DtoFeatureUsageInfo]] = None

    status: Optional[EventProcessingStatusType] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["debug_tracker", "event", "processed_events", "status"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
