"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_cancelschedulerequest as components_dto_cancelschedulerequest,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class CancelSubscriptionScheduleRequestTypedDict(TypedDict):
    schedule_id_param: str
    r"""Schedule ID (optional if using request body)"""
    body: NotRequired[
        components_dto_cancelschedulerequest.DtoCancelScheduleRequestTypedDict
    ]
    r"""Cancel request (optional if using path parameter)"""


class CancelSubscriptionScheduleRequest(BaseModel):
    schedule_id_param: Annotated[
        str,
        pydantic.Field(alias="schedule_id"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Schedule ID (optional if using request body)"""

    body: Annotated[
        Optional[components_dto_cancelschedulerequest.DtoCancelScheduleRequest],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None
    r"""Cancel request (optional if using path parameter)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
