"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_event import DtoEvent, DtoEventTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetEventsResponseTypedDict(TypedDict):
    events: NotRequired[List[DtoEventTypedDict]]
    has_more: NotRequired[bool]
    iter_first_key: NotRequired[str]
    iter_last_key: NotRequired[str]
    offset: NotRequired[int]
    total_count: NotRequired[int]


class DtoGetEventsResponse(BaseModel):
    events: Optional[List[DtoEvent]] = None

    has_more: Optional[bool] = None

    iter_first_key: Optional[str] = None

    iter_last_key: Optional[str] = None

    offset: Optional[int] = None

    total_count: Optional[int] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "events",
                "has_more",
                "iter_first_key",
                "iter_last_key",
                "offset",
                "total_count",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
