"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class MeterFilterTypedDict(TypedDict):
    key: NotRequired[str]
    r"""Key is the key for the filter from $event.properties
    Currently we support only first level keys in the properties and not nested keys
    """
    values: NotRequired[List[str]]
    r"""Values are the possible values for the filter to be considered for the meter
    For ex \"model_name\" could have values \"o1-mini\", \"gpt-4o\" etc
    """


class MeterFilter(BaseModel):
    key: Optional[str] = None
    r"""Key is the key for the filter from $event.properties
    Currently we support only first level keys in the properties and not nested keys
    """

    values: Optional[List[str]] = None
    r"""Values are the possible values for the filter to be considered for the meter
    For ex \"model_name\" could have values \"o1-mini\", \"gpt-4o\" etc
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["key", "values"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
