"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


AggregationType = Union[
    Literal[
        "COUNT",
        "SUM",
        "AVG",
        "COUNT_UNIQUE",
        "LATEST",
        "SUM_WITH_MULTIPLIER",
        "MAX",
        "WEIGHTED_SUM",
    ],
    UnrecognizedStr,
]
