"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel
from typing_extensions import TypedDict


class DtoActivateDraftSubscriptionRequestTypedDict(TypedDict):
    start_date: str
    r"""start_date is the new start date for the subscription when activating"""


class DtoActivateDraftSubscriptionRequest(BaseModel):
    start_date: str
    r"""start_date is the new start date for the subscription when activating"""
