"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usertype import UserType
from flexprice_py.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class DtoCreateUserRequestTypedDict(TypedDict):
    roles: List[str]
    r"""Roles are required"""
    type: UserType


class DtoCreateUserRequest(BaseModel):
    roles: List[str]
    r"""Roles are required"""

    type: UserType
