"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_aggregatedentitlement import (
    DtoAggregatedEntitlement,
    DtoAggregatedEntitlementTypedDict,
)
from .dto_entitlementsource import DtoEntitlementSource, DtoEntitlementSourceTypedDict
from .dto_featureresponse import DtoFeatureResponse, DtoFeatureResponseTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoAggregatedFeatureTypedDict(TypedDict):
    entitlement: NotRequired[DtoAggregatedEntitlementTypedDict]
    feature: NotRequired[DtoFeatureResponseTypedDict]
    sources: NotRequired[List[DtoEntitlementSourceTypedDict]]


class DtoAggregatedFeature(BaseModel):
    entitlement: Optional[DtoAggregatedEntitlement] = None

    feature: Optional[DtoFeatureResponse] = None

    sources: Optional[List[DtoEntitlementSource]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["entitlement", "feature", "sources"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
