"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetPreviewInvoiceRequestTypedDict(TypedDict):
    subscription_id: str
    r"""subscription_id is the unique identifier of the subscription to preview invoice for"""
    period_end: NotRequired[str]
    r"""period_end is the optional end date of the period to preview"""
    period_start: NotRequired[str]
    r"""period_start is the optional start date of the period to preview"""


class DtoGetPreviewInvoiceRequest(BaseModel):
    subscription_id: str
    r"""subscription_id is the unique identifier of the subscription to preview invoice for"""

    period_end: Optional[str] = None
    r"""period_end is the optional end date of the period to preview"""

    period_start: Optional[str] = None
    r"""period_start is the optional start date of the period to preview"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["period_end", "period_start"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
