"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoProrationDetailTypedDict(TypedDict):
    charge_amount: NotRequired[str]
    credit_amount: NotRequired[str]
    description: NotRequired[str]
    line_item_id: NotRequired[str]
    original_amount: NotRequired[str]
    plan_name: NotRequired[str]
    price_id: NotRequired[str]
    proration_days: NotRequired[int]


class DtoProrationDetail(BaseModel):
    charge_amount: Optional[str] = None

    credit_amount: Optional[str] = None

    description: Optional[str] = None

    line_item_id: Optional[str] = None

    original_amount: Optional[str] = None

    plan_name: Optional[str] = None

    price_id: Optional[str] = None

    proration_days: Optional[int] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "charge_amount",
                "credit_amount",
                "description",
                "line_item_id",
                "original_amount",
                "plan_name",
                "price_id",
                "proration_days",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
