"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_lineitemcommitmentconfig import (
    DtoLineItemCommitmentConfig,
    DtoLineItemCommitmentConfigTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoAddAddonRequestTypedDict(TypedDict):
    addon_id: str
    subscription_id: str
    line_item_commitments: NotRequired[Dict[str, DtoLineItemCommitmentConfigTypedDict]]
    r"""LineItemCommitments allows setting commitment configuration per addon line item (keyed by price_id)"""
    metadata: NotRequired[Dict[str, Any]]
    start_date: NotRequired[str]


class DtoAddAddonRequest(BaseModel):
    addon_id: str

    subscription_id: str

    line_item_commitments: Optional[Dict[str, DtoLineItemCommitmentConfig]] = None
    r"""LineItemCommitments allows setting commitment configuration per addon line item (keyed by price_id)"""

    metadata: Optional[Dict[str, Any]] = None

    start_date: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["line_item_commitments", "metadata", "start_date"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
