"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .couponcadence import CouponCadence
from .coupontype import CouponType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCreateCouponRequestTypedDict(TypedDict):
    cadence: CouponCadence
    name: str
    type: CouponType
    amount_off: NotRequired[str]
    currency: NotRequired[str]
    duration_in_periods: NotRequired[int]
    max_redemptions: NotRequired[int]
    metadata: NotRequired[Dict[str, str]]
    percentage_off: NotRequired[str]
    redeem_after: NotRequired[str]
    redeem_before: NotRequired[str]
    rules: NotRequired[Dict[str, Any]]


class DtoCreateCouponRequest(BaseModel):
    cadence: CouponCadence

    name: str

    type: CouponType

    amount_off: Optional[str] = None

    currency: Optional[str] = None

    duration_in_periods: Optional[int] = None

    max_redemptions: Optional[int] = None

    metadata: Optional[Dict[str, str]] = None

    percentage_off: Optional[str] = None

    redeem_after: Optional[str] = None

    redeem_before: Optional[str] = None

    rules: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "amount_off",
                "currency",
                "duration_in_periods",
                "max_redemptions",
                "metadata",
                "percentage_off",
                "redeem_after",
                "redeem_before",
                "rules",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
