"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


BillingPeriod = Union[
    Literal[
        "MONTHLY",
        "ANNUAL",
        "WEEKLY",
        "DAILY",
        "QUARTERLY",
        "HALF_YEARLY",
    ],
    UnrecognizedStr,
]
