"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_subscriptionpauseresponse import (
    DtoSubscriptionPauseResponse,
    DtoSubscriptionPauseResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoListSubscriptionPausesResponseTypedDict(TypedDict):
    r"""Response object for listing subscription pauses with total count"""

    items: NotRequired[List[DtoSubscriptionPauseResponseTypedDict]]
    r"""List of subscription pause objects
    @Description Array of subscription pauses
    """
    total: NotRequired[int]
    r"""Total number of pauses
    @Description Total count of subscription pauses in the response
    """


class DtoListSubscriptionPausesResponse(BaseModel):
    r"""Response object for listing subscription pauses with total count"""

    items: Optional[List[DtoSubscriptionPauseResponse]] = None
    r"""List of subscription pause objects
    @Description Array of subscription pauses
    """

    total: Optional[int] = None
    r"""Total number of pauses
    @Description Total count of subscription pauses in the response
    """

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["items", "total"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
