"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_triggerforcerunrequest as components_dto_triggerforcerunrequest,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class TriggerScheduledTaskRunRequestTypedDict(TypedDict):
    id: str
    r"""Scheduled Task ID"""
    body: NotRequired[
        components_dto_triggerforcerunrequest.DtoTriggerForceRunRequestTypedDict
    ]
    r"""Optional start and end time for custom range"""


class TriggerScheduledTaskRunRequest(BaseModel):
    id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""Scheduled Task ID"""

    body: Annotated[
        Optional[components_dto_triggerforcerunrequest.DtoTriggerForceRunRequest],
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ] = None
    r"""Optional start and end time for custom range"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["body"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
