"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .s3jobconfig import S3JobConfig, S3JobConfigTypedDict
from .scheduledtaskentitytype import ScheduledTaskEntityType
from .scheduledtaskinterval import ScheduledTaskInterval
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoScheduledTaskResponseTypedDict(TypedDict):
    connection_id: NotRequired[str]
    created_at: NotRequired[str]
    enabled: NotRequired[bool]
    entity_type: NotRequired[ScheduledTaskEntityType]
    environment_id: NotRequired[str]
    id: NotRequired[str]
    interval: NotRequired[ScheduledTaskInterval]
    job_config: NotRequired[S3JobConfigTypedDict]
    status: NotRequired[str]
    tenant_id: NotRequired[str]
    updated_at: NotRequired[str]


class DtoScheduledTaskResponse(BaseModel):
    connection_id: Optional[str] = None

    created_at: Optional[str] = None

    enabled: Optional[bool] = None

    entity_type: Optional[ScheduledTaskEntityType] = None

    environment_id: Optional[str] = None

    id: Optional[str] = None

    interval: Optional[ScheduledTaskInterval] = None

    job_config: Optional[S3JobConfig] = None

    status: Optional[str] = None

    tenant_id: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "connection_id",
                "created_at",
                "enabled",
                "entity_type",
                "environment_id",
                "id",
                "interval",
                "job_config",
                "status",
                "tenant_id",
                "updated_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
