"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .subscriptionschedulechangetype import SubscriptionScheduleChangeType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoCancelScheduleRequestTypedDict(TypedDict):
    r"""Request to cancel a subscription schedule (supports two modes)"""

    schedule_id: NotRequired[str]
    r"""schedule_id is the ID of the schedule to cancel (optional if subscription_id and schedule_type are provided)"""
    schedule_type: NotRequired[SubscriptionScheduleChangeType]
    subscription_id: NotRequired[str]
    r"""subscription_id is the ID of the subscription (required if schedule_id is not provided)"""


class DtoCancelScheduleRequest(BaseModel):
    r"""Request to cancel a subscription schedule (supports two modes)"""

    schedule_id: Optional[str] = None
    r"""schedule_id is the ID of the schedule to cancel (optional if subscription_id and schedule_type are provided)"""

    schedule_type: Optional[SubscriptionScheduleChangeType] = None

    subscription_id: Optional[str] = None
    r"""subscription_id is the ID of the subscription (required if schedule_id is not provided)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["schedule_id", "schedule_type", "subscription_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
