"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import Any, TYPE_CHECKING

from flexprice_py.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from . import components, operations

# package


_sub_packages = ["components", "operations"]


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports={}, sub_packages=_sub_packages
    )


def __dir__():
    return lazy_dir(dynamic_imports={}, sub_packages=_sub_packages)
