"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoFeatureUsageInfoTypedDict(TypedDict):
    customer_id: NotRequired[str]
    feature_id: NotRequired[str]
    meter_id: NotRequired[str]
    price_id: NotRequired[str]
    processed_at: NotRequired[str]
    qty_total: NotRequired[str]
    sub_line_item_id: NotRequired[str]
    subscription_id: NotRequired[str]


class DtoFeatureUsageInfo(BaseModel):
    customer_id: Optional[str] = None

    feature_id: Optional[str] = None

    meter_id: Optional[str] = None

    price_id: Optional[str] = None

    processed_at: Optional[str] = None

    qty_total: Optional[str] = None

    sub_line_item_id: Optional[str] = None

    subscription_id: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "customer_id",
                "feature_id",
                "meter_id",
                "price_id",
                "processed_at",
                "qty_total",
                "sub_line_item_id",
                "subscription_id",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
