"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


PaymentTerms = Union[
    Literal[
        "15 NET",
        "30 NET",
        "45 NET",
        "60 NET",
        "75 NET",
        "90 NET",
    ],
    UnrecognizedStr,
]
