"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


FailurePointType = Union[
    Literal[
        "customer_lookup",
        "meter_lookup",
        "price_lookup",
        "subscription_line_item_lookup",
    ],
    UnrecognizedStr,
]
