"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .integrationentitytype import IntegrationEntityType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoCreateEntityIntegrationMappingRequestTypedDict(TypedDict):
    entity_id: str
    entity_type: IntegrationEntityType
    provider_entity_id: str
    provider_type: str
    metadata: NotRequired[Dict[str, Any]]


class DtoCreateEntityIntegrationMappingRequest(BaseModel):
    entity_id: str

    entity_type: IntegrationEntityType

    provider_entity_id: str

    provider_type: str

    metadata: Optional[Dict[str, Any]] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["metadata"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
