"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .basesdk import BaseSDK
from flexprice_py import errors, models, utils
from flexprice_py._hooks import HookContext
from flexprice_py.types import OptionalNullable, UNSET
from flexprice_py.utils.unmarshal_json_response import unmarshal_json_response
from typing import Any, List, Mapping, Optional, Union


class Workflows(BaseSDK):
    def query_workflow(
        self,
        *,
        end_time: Optional[str] = None,
        entity: Optional[str] = None,
        entity_id: Optional[str] = None,
        expand: Optional[str] = None,
        filters: Optional[
            Union[
                List[models.components.FilterCondition],
                List[models.components.FilterConditionTypedDict],
            ]
        ] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        order: Optional[models.components.WorkflowExecutionFilterOrder] = None,
        sort: Optional[
            Union[
                List[models.components.SortCondition],
                List[models.components.SortConditionTypedDict],
            ]
        ] = None,
        start_time: Optional[str] = None,
        status: Optional[models.components.Status] = None,
        task_queue: Optional[str] = None,
        workflow_id: Optional[str] = None,
        workflow_status: Optional[str] = None,
        workflow_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.components.DtoListWorkflowsResponse:
        r"""Query workflows

        Use when listing or auditing workflow runs (e.g. ops dashboard or debugging). Returns a paginated list; supports filtering by workflow type and status.

        :param end_time:
        :param entity: e.g. plan, invoice, subscription
        :param entity_id: e.g. plan_01ABC123
        :param expand:
        :param filters: filters allows complex filtering based on multiple fields (same as FeatureFilter)
        :param limit:
        :param offset:
        :param order:
        :param sort:
        :param start_time:
        :param status:
        :param task_queue:
        :param workflow_id: Workflow-specific filters
        :param workflow_status: e.g. Running, Completed, Failed
        :param workflow_type:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.components.WorkflowExecutionFilter(
            end_time=end_time,
            entity=entity,
            entity_id=entity_id,
            expand=expand,
            filters=utils.get_pydantic_model(
                filters, Optional[List[models.components.FilterCondition]]
            ),
            limit=limit,
            offset=offset,
            order=order,
            sort=utils.get_pydantic_model(
                sort, Optional[List[models.components.SortCondition]]
            ),
            start_time=start_time,
            status=status,
            task_queue=task_queue,
            workflow_id=workflow_id,
            workflow_status=workflow_status,
            workflow_type=workflow_type,
        )

        req = self._build_request(
            method="POST",
            path="/workflows/search",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.components.WorkflowExecutionFilter
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = self.do_request(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="queryWorkflow",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.components.DtoListWorkflowsResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.ErrorsErrorResponseData, http_res
            )
            raise errors.ErrorsErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.ErrorsErrorResponseData, http_res
            )
            raise errors.ErrorsErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FlexpriceDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = utils.stream_to_text(http_res)
            raise errors.FlexpriceDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FlexpriceDefaultError("Unexpected response received", http_res)

    async def query_workflow_async(
        self,
        *,
        end_time: Optional[str] = None,
        entity: Optional[str] = None,
        entity_id: Optional[str] = None,
        expand: Optional[str] = None,
        filters: Optional[
            Union[
                List[models.components.FilterCondition],
                List[models.components.FilterConditionTypedDict],
            ]
        ] = None,
        limit: Optional[int] = None,
        offset: Optional[int] = None,
        order: Optional[models.components.WorkflowExecutionFilterOrder] = None,
        sort: Optional[
            Union[
                List[models.components.SortCondition],
                List[models.components.SortConditionTypedDict],
            ]
        ] = None,
        start_time: Optional[str] = None,
        status: Optional[models.components.Status] = None,
        task_queue: Optional[str] = None,
        workflow_id: Optional[str] = None,
        workflow_status: Optional[str] = None,
        workflow_type: Optional[str] = None,
        retries: OptionalNullable[utils.RetryConfig] = UNSET,
        server_url: Optional[str] = None,
        timeout_ms: Optional[int] = None,
        http_headers: Optional[Mapping[str, str]] = None,
    ) -> models.components.DtoListWorkflowsResponse:
        r"""Query workflows

        Use when listing or auditing workflow runs (e.g. ops dashboard or debugging). Returns a paginated list; supports filtering by workflow type and status.

        :param end_time:
        :param entity: e.g. plan, invoice, subscription
        :param entity_id: e.g. plan_01ABC123
        :param expand:
        :param filters: filters allows complex filtering based on multiple fields (same as FeatureFilter)
        :param limit:
        :param offset:
        :param order:
        :param sort:
        :param start_time:
        :param status:
        :param task_queue:
        :param workflow_id: Workflow-specific filters
        :param workflow_status: e.g. Running, Completed, Failed
        :param workflow_type:
        :param retries: Override the default retry configuration for this method
        :param server_url: Override the default server URL for this method
        :param timeout_ms: Override the default request timeout configuration for this method in milliseconds
        :param http_headers: Additional headers to set or replace on requests.
        """
        base_url = None
        url_variables = None
        if timeout_ms is None:
            timeout_ms = self.sdk_configuration.timeout_ms

        if server_url is not None:
            base_url = server_url
        else:
            base_url = self._get_url(base_url, url_variables)

        request = models.components.WorkflowExecutionFilter(
            end_time=end_time,
            entity=entity,
            entity_id=entity_id,
            expand=expand,
            filters=utils.get_pydantic_model(
                filters, Optional[List[models.components.FilterCondition]]
            ),
            limit=limit,
            offset=offset,
            order=order,
            sort=utils.get_pydantic_model(
                sort, Optional[List[models.components.SortCondition]]
            ),
            start_time=start_time,
            status=status,
            task_queue=task_queue,
            workflow_id=workflow_id,
            workflow_status=workflow_status,
            workflow_type=workflow_type,
        )

        req = self._build_request_async(
            method="POST",
            path="/workflows/search",
            base_url=base_url,
            url_variables=url_variables,
            request=request,
            request_body_required=True,
            request_has_path_params=False,
            request_has_query_params=True,
            user_agent_header="user-agent",
            accept_header_value="application/json",
            http_headers=http_headers,
            security=self.sdk_configuration.security,
            get_serialized_body=lambda: utils.serialize_request_body(
                request, False, False, "json", models.components.WorkflowExecutionFilter
            ),
            allow_empty_value=None,
            timeout_ms=timeout_ms,
        )

        if retries == UNSET:
            if self.sdk_configuration.retry_config is not UNSET:
                retries = self.sdk_configuration.retry_config

        retry_config = None
        if isinstance(retries, utils.RetryConfig):
            retry_config = (retries, ["429", "500", "502", "503", "504"])

        http_res = await self.do_request_async(
            hook_ctx=HookContext(
                config=self.sdk_configuration,
                base_url=base_url or "",
                operation_id="queryWorkflow",
                oauth2_scopes=None,
                security_source=self.sdk_configuration.security,
            ),
            request=req,
            error_status_codes=["400", "4XX", "500", "5XX"],
            retry_config=retry_config,
        )

        response_data: Any = None
        if utils.match_response(http_res, "200", "application/json"):
            return unmarshal_json_response(
                models.components.DtoListWorkflowsResponse, http_res
            )
        if utils.match_response(http_res, "400", "application/json"):
            response_data = unmarshal_json_response(
                errors.ErrorsErrorResponseData, http_res
            )
            raise errors.ErrorsErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "500", "application/json"):
            response_data = unmarshal_json_response(
                errors.ErrorsErrorResponseData, http_res
            )
            raise errors.ErrorsErrorResponse(response_data, http_res)
        if utils.match_response(http_res, "4XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FlexpriceDefaultError(
                "API error occurred", http_res, http_res_text
            )
        if utils.match_response(http_res, "5XX", "*"):
            http_res_text = await utils.stream_to_text_async(http_res)
            raise errors.FlexpriceDefaultError(
                "API error occurred", http_res, http_res_text
            )

        raise errors.FlexpriceDefaultError("Unexpected response received", http_res)
