"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from .flexpriceerror import FlexpriceError
from typing import Any, TYPE_CHECKING

from flexprice_py.utils.dynamic_imports import lazy_getattr, lazy_dir

if TYPE_CHECKING:
    from .errors_errorresponse import ErrorsErrorResponse, ErrorsErrorResponseData
    from .flexpricedefaulterror import FlexpriceDefaultError
    from .no_response_error import NoResponseError
    from .responsevalidationerror import ResponseValidationError

__all__ = [
    "ErrorsErrorResponse",
    "ErrorsErrorResponseData",
    "FlexpriceDefaultError",
    "FlexpriceError",
    "NoResponseError",
    "ResponseValidationError",
]

_dynamic_imports: dict[str, str] = {
    "ErrorsErrorResponse": ".errors_errorresponse",
    "ErrorsErrorResponseData": ".errors_errorresponse",
    "FlexpriceDefaultError": ".flexpricedefaulterror",
    "NoResponseError": ".no_response_error",
    "ResponseValidationError": ".responsevalidationerror",
}


def __getattr__(attr_name: str) -> Any:
    return lazy_getattr(
        attr_name, package=__package__, dynamic_imports=_dynamic_imports
    )


def __dir__():
    return lazy_dir(dynamic_imports=_dynamic_imports)
