"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_customanalyticitem import (
    DtoCustomAnalyticItem,
    DtoCustomAnalyticItemTypedDict,
)
from .dto_usageanalyticitem import DtoUsageAnalyticItem, DtoUsageAnalyticItemTypedDict
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoGetUsageAnalyticsResponseTypedDict(TypedDict):
    currency: NotRequired[str]
    custom_analytics: NotRequired[List[DtoCustomAnalyticItemTypedDict]]
    items: NotRequired[List[DtoUsageAnalyticItemTypedDict]]
    total_cost: NotRequired[str]


class DtoGetUsageAnalyticsResponse(BaseModel):
    currency: Optional[str] = None

    custom_analytics: Optional[List[DtoCustomAnalyticItem]] = None

    items: Optional[List[DtoUsageAnalyticItem]] = None

    total_cost: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["currency", "custom_analytics", "items", "total_cost"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
