"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_updatecustomerrequest as components_dto_updatecustomerrequest,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from flexprice_py.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from pydantic import model_serializer
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class UpdateCustomerRequestTypedDict(TypedDict):
    body: components_dto_updatecustomerrequest.DtoUpdateCustomerRequestTypedDict
    r"""Customer"""
    id: NotRequired[str]
    r"""Customer ID"""
    external_customer_id: NotRequired[str]
    r"""Customer External ID"""


class UpdateCustomerRequest(BaseModel):
    body: Annotated[
        components_dto_updatecustomerrequest.DtoUpdateCustomerRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Customer"""

    id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Customer ID"""

    external_customer_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None
    r"""Customer External ID"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["id", "external_customer_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
