"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cancelimmediatelyinvoicepolicy import CancelImmediatelyInvoicePolicy
from .cancellationtype import CancellationType
from .prorationbehavior import ProrationBehavior
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoCancelSubscriptionRequestTypedDict(TypedDict):
    cancellation_type: CancellationType
    cancel_immediately_inovice_policy: NotRequired[CancelImmediatelyInvoicePolicy]
    proration_behavior: NotRequired[ProrationBehavior]
    reason: NotRequired[str]
    r"""Reason for cancellation (for audit and business intelligence)"""


class DtoCancelSubscriptionRequest(BaseModel):
    cancellation_type: CancellationType

    cancel_immediately_inovice_policy: Optional[CancelImmediatelyInvoicePolicy] = None

    proration_behavior: Optional[ProrationBehavior] = None

    reason: Optional[str] = None
    r"""Reason for cancellation (for audit and business intelligence)"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["cancel_immediately_inovice_policy", "proration_behavior", "reason"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
