"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_tenantresponse import DtoTenantResponse, DtoTenantResponseTypedDict
from .usertype import UserType
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoUserResponseTypedDict(TypedDict):
    email: NotRequired[str]
    r"""Empty for service accounts"""
    id: NotRequired[str]
    roles: NotRequired[List[str]]
    tenant: NotRequired[DtoTenantResponseTypedDict]
    type: NotRequired[UserType]


class DtoUserResponse(BaseModel):
    email: Optional[str] = None
    r"""Empty for service accounts"""

    id: Optional[str] = None

    roles: Optional[List[str]] = None

    tenant: Optional[DtoTenantResponse] = None

    type: Optional[UserType] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["email", "id", "roles", "tenant", "type"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
