"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import UnrecognizedStr
from typing import Literal, Union


PaymentStatus = Union[
    Literal[
        "INITIATED",
        "PENDING",
        "PROCESSING",
        "SUCCEEDED",
        "OVERPAID",
        "FAILED",
        "REFUNDED",
        "PARTIALLY_REFUNDED",
    ],
    UnrecognizedStr,
]
