"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoEventTypedDict(TypedDict):
    customer_id: NotRequired[str]
    environment_id: NotRequired[str]
    event_name: NotRequired[str]
    external_customer_id: NotRequired[str]
    id: NotRequired[str]
    properties: NotRequired[Dict[str, Any]]
    source: NotRequired[str]
    timestamp: NotRequired[str]


class DtoEvent(BaseModel):
    customer_id: Optional[str] = None

    environment_id: Optional[str] = None

    event_name: Optional[str] = None

    external_customer_id: Optional[str] = None

    id: Optional[str] = None

    properties: Optional[Dict[str, Any]] = None

    source: Optional[str] = None

    timestamp: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "customer_id",
                "environment_id",
                "event_name",
                "external_customer_id",
                "id",
                "properties",
                "source",
                "timestamp",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
