"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class DtoIngestEventRequestTypedDict(TypedDict):
    event_name: str
    external_customer_id: str
    customer_id: NotRequired[str]
    event_id: NotRequired[str]
    properties: NotRequired[Dict[str, str]]
    r"""Handled separately for dynamic columns"""
    source: NotRequired[str]
    timestamp: NotRequired[str]
    r"""Handled separately due to parsing"""


class DtoIngestEventRequest(BaseModel):
    event_name: str

    external_customer_id: str

    customer_id: Optional[str] = None

    event_id: Optional[str] = None

    properties: Optional[Dict[str, str]] = None
    r"""Handled separately for dynamic columns"""

    source: Optional[str] = None

    timestamp: Optional[str] = None
    r"""Handled separately due to parsing"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            ["customer_id", "event_id", "properties", "source", "timestamp"]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
