"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.models.components import (
    dto_createintegrationrequest as components_dto_createintegrationrequest,
)
from flexprice_py.types import BaseModel
from flexprice_py.utils import FieldMetadata, PathParamMetadata, RequestMetadata
import pydantic
from typing_extensions import Annotated, TypedDict


class CreateOrUpdateIntegrationRequestTypedDict(TypedDict):
    provider_param: str
    r"""Integration provider"""
    body: components_dto_createintegrationrequest.DtoCreateIntegrationRequestTypedDict
    r"""Integration creation request"""


class CreateOrUpdateIntegrationRequest(BaseModel):
    provider_param: Annotated[
        str,
        pydantic.Field(alias="provider"),
        FieldMetadata(path=PathParamMetadata(style="simple", explode=False)),
    ]
    r"""Integration provider"""

    body: Annotated[
        components_dto_createintegrationrequest.DtoCreateIntegrationRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
    r"""Integration creation request"""
