"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ModelsTemporalWorkflowResultTypedDict(TypedDict):
    message: NotRequired[str]
    run_id: NotRequired[str]
    workflow_id: NotRequired[str]


class ModelsTemporalWorkflowResult(BaseModel):
    message: Optional[str] = None

    run_id: Optional[str] = None

    workflow_id: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["message", "run_id", "workflow_id"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
