"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoUsageAnalyticPointTypedDict(TypedDict):
    computed_commitment_utilized_amount: NotRequired[str]
    r"""Commitment breakdown (only populated for windowed commitments)"""
    computed_overage_amount: NotRequired[str]
    computed_true_up_amount: NotRequired[str]
    cost: NotRequired[str]
    event_count: NotRequired[int]
    r"""Number of events in this time window"""
    timestamp: NotRequired[str]
    usage: NotRequired[str]


class DtoUsageAnalyticPoint(BaseModel):
    computed_commitment_utilized_amount: Optional[str] = None
    r"""Commitment breakdown (only populated for windowed commitments)"""

    computed_overage_amount: Optional[str] = None

    computed_true_up_amount: Optional[str] = None

    cost: Optional[str] = None

    event_count: Optional[int] = None
    r"""Number of events in this time window"""

    timestamp: Optional[str] = None

    usage: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "computed_commitment_utilized_amount",
                "computed_overage_amount",
                "computed_true_up_amount",
                "cost",
                "event_count",
                "timestamp",
                "usage",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
