"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel
from typing_extensions import TypedDict


class ScheduleUpdateBillingPeriodRequestTypedDict(TypedDict):
    r"""Schedule Update Billing Period Request"""


class ScheduleUpdateBillingPeriodRequest(BaseModel):
    r"""Schedule Update Billing Period Request"""


class ScheduleUpdateBillingPeriodResponseTypedDict(TypedDict):
    r"""OK"""


class ScheduleUpdateBillingPeriodResponse(BaseModel):
    r"""OK"""
