"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .secretprovider import SecretProvider
from flexprice_py.types import BaseModel
from typing import Dict
from typing_extensions import TypedDict


class DtoCreateIntegrationRequestTypedDict(TypedDict):
    credentials: Dict[str, str]
    name: str
    provider: SecretProvider


class DtoCreateIntegrationRequest(BaseModel):
    credentials: Dict[str, str]

    name: str

    provider: SecretProvider
