"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from flexprice_py.types import BaseModel, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GithubComFlexpriceFlexpriceInternalTypesValueTypedDict(TypedDict):
    array: NotRequired[List[str]]
    boolean: NotRequired[bool]
    date_: NotRequired[str]
    number: NotRequired[float]
    string: NotRequired[str]


class GithubComFlexpriceFlexpriceInternalTypesValue(BaseModel):
    array: Optional[List[str]] = None

    boolean: Optional[bool] = None

    date_: Annotated[Optional[str], pydantic.Field(alias="date")] = None

    number: Optional[float] = None

    string: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["array", "boolean", "date", "number", "string"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m


try:
    GithubComFlexpriceFlexpriceInternalTypesValue.model_rebuild()
except NameError:
    pass
