"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dto_walletresponse import DtoWalletResponse, DtoWalletResponseTypedDict
from .dto_wallettransactionresponse import (
    DtoWalletTransactionResponse,
    DtoWalletTransactionResponseTypedDict,
)
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DtoTopUpWalletResponseTypedDict(TypedDict):
    invoice_id: NotRequired[str]
    r"""Invoice ID if an invoice was created (only for PURCHASED_CREDIT_INVOICED)"""
    wallet: NotRequired[DtoWalletResponseTypedDict]
    wallet_transaction: NotRequired[DtoWalletTransactionResponseTypedDict]


class DtoTopUpWalletResponse(BaseModel):
    invoice_id: Optional[str] = None
    r"""Invoice ID if an invoice was created (only for PURCHASED_CREDIT_INVOICED)"""

    wallet: Optional[DtoWalletResponse] = None

    wallet_transaction: Optional[DtoWalletTransactionResponse] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(["invoice_id", "wallet", "wallet_transaction"])
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
