"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .meter_aggregation import MeterAggregation, MeterAggregationTypedDict
from .meter_filter import MeterFilter, MeterFilterTypedDict
from .resetusage import ResetUsage
from flexprice_py.types import BaseModel, UNSET_SENTINEL
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class DtoMeterResponseTypedDict(TypedDict):
    aggregation: NotRequired[MeterAggregationTypedDict]
    created_at: NotRequired[str]
    event_name: NotRequired[str]
    filters: NotRequired[List[MeterFilterTypedDict]]
    id: NotRequired[str]
    name: NotRequired[str]
    reset_usage: NotRequired[ResetUsage]
    status: NotRequired[str]
    tenant_id: NotRequired[str]
    updated_at: NotRequired[str]


class DtoMeterResponse(BaseModel):
    aggregation: Optional[MeterAggregation] = None

    created_at: Optional[str] = None

    event_name: Optional[str] = None

    filters: Optional[List[MeterFilter]] = None

    id: Optional[str] = None

    name: Optional[str] = None

    reset_usage: Optional[ResetUsage] = None

    status: Optional[str] = None

    tenant_id: Optional[str] = None

    updated_at: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = set(
            [
                "aggregation",
                "created_at",
                "event_name",
                "filters",
                "id",
                "name",
                "reset_usage",
                "status",
                "tenant_id",
                "updated_at",
            ]
        )
        serialized = handler(self)
        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)

            if val != UNSET_SENTINEL:
                if val is not None or k not in optional_fields:
                    m[k] = val

        return m
